========================
Deployment configuration
========================

This section describes configuration of kolla containers, including limiting
their resources.

.. toctree::
   :maxdepth: 1

   resource-constraints
